@@ -39,6 +39,7 @@ typedef struct rect {
 	
 Rect* new_rect(unsigned int d);
 Rect* new_dup_rect(Rect* oldR);
+Rect* new_drect(double **drect, int d);
 void delete_rect(Rect* rect);
 unsigned int matrix_constrained(int *p, double **X, unsigned int n1, unsigned int n2, 
 				Rect *rect);
@@ -50,11 +51,15 @@ double **get_data_rect(double **X, unsigned int N, unsigned int d);
 
 void normalize(double **Xall, double **rect, int N, int d, double normscale);
 void zero(double **M, unsigned int n1, unsigned int n2);
+int isZero(double **M, unsigned int m, int sym);
 void id(double **M, unsigned int n);
 double ** new_id_matrix(unsigned int n);
 double ** new_zero_matrix(unsigned int n1, unsigned int n2);
 double ** new_matrix(unsigned int m, unsigned int n);
 double ** new_matrix_bones(double *v, unsigned int n1, unsigned int n2);
+int ** new_imatrix_bones(int *v, unsigned int n1, unsigned int n2);
+int ** new_t_imatrix(int** M, unsigned int n1, unsigned int n2);
+int ** new_imatrix(unsigned int n1, unsigned int n2);
 double ** new_t_matrix(double** M, unsigned int n1_old, unsigned int n2_old);
 double ** new_dup_matrix(double** M, unsigned int n1, unsigned int n2);
 double ** new_shift_matrix(double** M, unsigned int n1, unsigned int n2);
@@ -77,6 +82,8 @@ void sum_of_each_column_f(double *s, double **M, unsigned int *n1,
 			  unsigned int n2, double(*f)(double));
 void wmean_of_columns(double *mean, double **M, unsigned int n1, unsigned int n2, 
 		      double *weight);
+void wvar_of_columns(double *var, double **M, unsigned int n1, unsigned int n2,
+		     double *weight);
 void wmean_of_columns_f(double *mean, double **M, unsigned int n1, unsigned int n2, 
 			double *weight, double(*f)(double));
 void wmean_of_rows(double *mean, double **M, unsigned int n1, unsigned int n2, 
@@ -90,9 +97,10 @@ void wcovx_of_columns(double **cov, double **M1, double **M2, double *mean1, dou
 
 void add_matrix(double a, double **M1, double b, double **M2, unsigned int n1, 
 		unsigned int n2);
-double **new_p_submatrix(int *p, double **v, unsigned int nrows, unsigned int ncols);
-void sub_p_matrix(double **V, int *p, double **v, 
-		  unsigned int nrows, unsigned int lenp);
+double **new_p_submatrix(int *p, double **v, unsigned int nrows, unsigned int ncols,
+			 unsigned int col_offset);
+void sub_p_matrix(double **V, int *p, double **v, unsigned int nrows, 
+		  unsigned int lenp, unsigned int col_offset);
 void copy_p_matrix(double **V, int *p1, int *p2, double **v, unsigned int n1, 
 		   unsigned int n2);
 void add_p_matrix(double a, double **V, int *p1, int *p2, double b, double **v, 
@@ -103,8 +111,8 @@ double* dseq(double from, double to, double by);
 int* iseq(double from, double to);
  
 int* find(double *V, unsigned int n, FIND_OP op, double val, unsigned int* len);
-int* find_col(double **V, unsigned int n, unsigned int var, FIND_OP op, 
-	double val, unsigned int* len);
+int* find_col(double **V, int *p, unsigned int n, unsigned int var, 
+	      FIND_OP op, double val, unsigned int* len);
 
 double kth_smallest(double a[], int n, int k);
 double quick_select(double arr[], int n, int k);
